@@ -37,7 +37,7 @@
   mapsup mapsdown longmapsup longmapsdown
   upsquigarrow downsquigarrow updownsquigarrow
   hookuparrow hookdownarrow longhookuparrow longhookdownarrow
-  Backepsilon Mho btimes
+  Backepsilon Backsigma Mho btimes
 
   ;; asymptotic relations by Joris
   nasymp asympasymp nasympasymp simsim nsimsim
@@ -45,22 +45,33 @@
   succsucc succsucceq succsuccsucc succsuccsucceq
   lleq llleq ggeq gggeq triplesim ntriplesim
 
+  ;; replacements for symbols from mathabx
+  divides ndivides asterisk dottimes precdot
+
   ;; extra literal symbols
   mathcatalan mathd mathD mathe matheuler mathlambda mathi mathpi
   Alpha Beta Epsilon Eta Iota Kappa Mu Nu Omicron Chi Rho Tau Zeta
 
-  ;; other extra symbols
-  exterior Exists bigintwl bigointwl
-  of asterisk point cdummy comma copyright
-  bignone nobracket nospace nocomma noplus nosymbol
+  ;; negations
   nin nni notni nequiv nleadsto
+  npreccurlyeq npreceqq nprecsim
+  nsimeq nsqsubset nsqsubseteq nsqsubseteqq
+  nsqsupset nsqsupseteq nsqsupseteqq
+  nsucccurlyeq nsucceqq nsuccsim  
+  
+  ;; other extra symbols
+  oempty exterior Exists bigintwl bigointwl
+  of suchthat barsuchthat asterisk point cdummy comma copyright
+  bignone nobracket nospace nocomma noplus nosymbol
   dotminus dotpm dotmp dotamalg dottimes dotoplus dototimes dotast
   into longminus longequal
   longhookrightarrow longhookleftarrow
   triangleup tmprecdot preceqdot
-  llangle rrangle join um upl upm ump
+  llangle rrangle join um upl upm ump pplus
   assign plusassign minusassign timesassign overassign backassign
-  lflux gflux colons transtype udots subsetsim supsetsim
+  lflux gflux colons transtype
+  lebar gebar leangle geangle leqangle geqangle
+  udots subsetsim supsetsim
   rightmap leftmap leftrightmap)
 
 (logic-rules
@@ -73,8 +84,8 @@
 
 (logic-group latex-texmacs-0%
   tmunsc emdash tmhrule tmat tmbsl tmdummy
-  TeXmacs madebyTeXmacs withTeXmacstext
-  scheme tmsep tmSep pari qed hrule)
+  TeXmacs madebyTeXmacs withTeXmacstext tmmade
+  scheme tmsep tmSep pari qed textdots hrule)
 
 (logic-group latex-texmacs-1%
   key tmrsub tmrsup keepcase
@@ -105,11 +116,11 @@
   tmfoldedplain tmunfoldedplain tmfoldedenv tmunfoldedenv
   tmfoldedstd tmunfoldedstd tmfolded tmunfolded
   tminput tminputmath tmhlink tmaction ontop subindex
-  renderfootnote)
+  renderfootnote tmlinenumber)
 
 (logic-group latex-texmacs-3%
   tmsession tmfoldedio tmunfoldedio tmfoldediomath tmunfoldediomath
-  subsubindex tmref glossaryentry)
+  tmlinenote subsubindex tmref glossaryentry natbib-triple)
 
 (logic-group latex-texmacs-4%
   tmscriptinput tmscriptoutput tmconverterinput tmconverteroutput
@@ -149,6 +160,7 @@
   ("tmparmod" 3)
   ("tmparsep" 1)
   ("tmindent" 0)
+  ("tmlisting" 0)
   ("elsequation" 0)
   ("elsequation*" 0)
   ("theglossary" 1))
@@ -158,7 +170,7 @@
 
 (logic-group latex-texmacs-environment-0%
   begin-proof begin-leftaligned begin-rightaligned begin-quoteenv
-  begin-tmindent begin-elsequation begin-elsequation*)
+  begin-tmindent begin-tmlisting begin-elsequation begin-elsequation*)
 
 (logic-group latex-texmacs-environment-0*%
   begin-tmcode)
@@ -214,7 +226,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (logic-group latex-texmacs-preamble-command%
-  newmdenv
+  newmdenv tikzframe
   tmkeywords tmacm tmarxiv tmpacs tmmsc
   fmtext tdatetext tmisctext tsubtitletext
   thankshomepage thanksemail thanksdate thanksamisc thanksmisc thankssubtitle
@@ -236,14 +248,26 @@
   "axiom" "definition" "notation" "conjecture"
   "remark" "note" "example" "convention"
   "warning" "acknowledgments" "answer" "question"
-  "exercise" "problem" "solution")
+  "exercise" "problem" "solution"
+
+  "theorem*" "proposition*" "lemma*" "corollary*"
+  "axiom*" "definition*" "notation*" "conjecture*"
+  "remark*" "note*" "example*" "convention*"
+  "warning*" "acknowledgments*" "answer*" "question*"
+  "exercise*" "problem*" "solution*")
 
 (logic-group latex-texmacs-theorem%
   begin-theorem begin-proposition begin-lemma begin-corollary
   begin-axiom begin-definition begin-notation begin-conjecture
   begin-remark begin-note begin-example begin-convention
   begin-warning begin-acknowledgments begin-answer begin-question
-  begin-exercise begin-problem begin-solution)
+  begin-exercise begin-problem begin-solution
+
+  begin-theorem* begin-proposition* begin-lemma* begin-corollary*
+  begin-axiom* begin-definition* begin-notation* begin-conjecture*
+  begin-remark* begin-note* begin-example* begin-convention*
+  begin-warning* begin-acknowledgments* begin-answer* begin-question*
+  begin-exercise* begin-problem* begin-solution*)
 
 (logic-rules
   ((latex-texmacs-arity% 'x 0) (latex-texmacs-theorem% 'x))
