@@ -40,7 +40,7 @@
     (shortcut :menu-wide-label :string?)))
   (:menu-item (:or
     ---
-    |
+    | ;; |
     (group :%1)
     (text :%1)
     (glue :boolean? :boolean? :integer? :integer?)
@@ -362,6 +362,14 @@
         (menu-label-add-dots label)
         label)))
 
+(define (make-menu-entry-style style action)
+  (with source (promise-source action)
+    (if (not (pair? source)) style
+	(with prop (property (car source) :applicable)
+	  (if (or (not prop) (apply (car prop) (list)))
+	      style
+	      (logior style (+ widget-style-inert widget-style-grey)))))))
+
 (define (make-menu-entry-attrs label action opt-key opt-check)
   (cond ((match? label '(shortcut :%1 :string?))
          (make-menu-entry-attrs (cadr label) action (caddr label) opt-check))
@@ -374,7 +382,9 @@
       (label action opt-key opt-check)
       (make-menu-entry-attrs (car p) (cAr p) #f #f)
     (make-menu-entry-button
-     style bar? (tuple? (car p) 'balloon 2)
+     (make-menu-entry-style style action)
+     bar?
+     (tuple? (car p) 'balloon 2)
      (make-menu-entry-check opt-check action)
      (make-menu-entry-dots label action)
      (make-menu-entry-shortcut label action opt-key)
@@ -656,7 +666,7 @@
             (else
              (make-menu-items-list p style bar?)))
       (cond ((== p '---) (list (make-menu-hsep)))
-            ((== p '|) (list (make-menu-vsep)))
+            ((== p '|) (list (make-menu-vsep))) ;; '|
             ((== p '()) p)
             (else (list (make-menu-bad-format p style))))))
 
@@ -872,6 +882,15 @@
          (replace-procedures p))
         (else (menu-expand-list p))))
 
+(tm-define (cache-menu? r)
+  (:type (-> object bool))
+  (:synopsis "Cache expanded menu @r.")
+  (cond ((symbol? r) (!= r 'input))
+        ((pair? r)
+         (and (cache-menu? (car r))
+              (cache-menu? (cdr r))))
+        (else #t)))
+
 (define-table menu-expand-table
   (--- ,(lambda (p) `(--- ,@(menu-expand-list (cdr p)))))
   (| ,(lambda (p) `(| ,@(menu-expand-list (cdr p)))))
@@ -1010,6 +1029,7 @@
 
 (tm-define (interactive-color cmd proposals)
   (:interactive #t)
+  (set! proposals (map tm->tree proposals))
   (if (not (qt-gui?))
       (interactive-rgb-picker cmd proposals)
       (with p (lambda (com) (widget-color-picker com #f proposals))
@@ -1018,6 +1038,7 @@
 
 (tm-define (interactive-background cmd proposals)
   (:interactive #t)
+  (set! proposals (map tm->tree proposals))
   (if (not (qt-gui?))
       (interactive-rgb-picker cmd proposals)
       ;;(with p (lambda (com) (widget-color-picker com #t proposals))
